/* RCS Information:
 *
 * $Id$
 * $Revision$
 * $Date$
 * $Author$
 * $Locker$
 * 
 */

/******************************************************************************
 *
 *  Copyright (C) 2001, Bill Pierce
 *  This file is part of the timeout_action library.
 *
 *  The timeout_action library is free software; you can 
 *  redistribute it and/or modify it under the terms of the 
 *  GNU Library General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The timeout_action library is distributed in the hope that 
 *  it will be useful, but WITHOUT ANY WARRANTY; without even 
 *  the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 *  PARTICULAR PURPOSE.  See the GNU Library General Public 
 *  License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with the timeout action libary; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Bill Pierce can be contacted at:
 *  7862 NE 148th St.
 *  Kenmore, WA 98028
 *
 * Name -- timeout_action.h 
 *
 * Purpose --  Header file for the timeout_action library routines. 
 *
 * Remarks --  
 *
 * Known bugs --  
 *
 * Applicable Invariants -- 
 * 
 * Code using this library should be compiled and linked 
 * with REENTRANT flags set.
 *
 * Language Version --  C - GNU/Linux 
 *
 * Author --  Bill Pierce
 * 
 *****************************************************************************/

 /* Define return codes. */
 #define TIMEOUT_ACTION_CODE_ERROR   0
 #define TIMEOUT_ACTION_CODE_SUCCESS 1
 #define TIMEOUT_ACTION_CODE_TIMEOUT 2

 /*
  * This prototype defines the portable timeout_action call.
  * This provides a way to execute a function in such a way
  * that the calling thread will block until either the 
  * function occurs, or a specified amount of time elapses.
  *
  * p_function is a pointer to the function that is to be 
  * This function must take and return a void pointer.
  * Whether or not the function is able to execute completely
  * in the specified time, it will be allowed to run to 
  * completion in its own thread when it executes.
  *
  * p_arg is a void pointer to an argument to the function
  * pointed to by p_function.
  *
  * timeout_in_ms is the timeout value in milliseconds.
  * if p_function does not complete execution in this
  * time, timeout_action will return.
  *
  * pp_return_value is a pointer to a pointer to 
  * the return value to the function. That is, this
  * pointer will be set to point to a pointer to void
  * that is the return value of p_function.  This value
  * can be expected to contain useful data only if 
  * timeout_action returns TIMEOUT_ACTION_CODE_SUCCESS.
  *
  * This function returns one of three values to indicate
  * the course this action took.
  * 
  * TIMEOUT_ACTION_CODE_ERROR indicates an error occurred
  * while trying to execute the timeout action.  Note that
  * this is distinct from the an error occuring during execution
  * of p_function.  The latter must be indicated within the 
  * confines of the structure pointed to by pp_return_value.
  *
  * TIMEOUT_ACTION_CODE_SUCCESS indicates that p_function completed
  * successfully before the timer timed out. pp_return_value
  * contains a pointer to the return_value.
  *
  * TIMEOUT_ACTION_CODE_TIMEOUT indicates that the timer timed
  * out before the action completed.  pp_return value
  * has not been set. 
  *  
  */
 int timeout_action( void* p_function (void*), 
                     void* p_arg,
                     unsigned int timeout_in_ms,
                     void** pp_return_value 
                   );

 /*****************************************************************************
 ** $Log: $
 *****************************************************************************/

